Class: MasterCard::API::Mastercom::ChargebacksDebitMasterCardAndEuropeDualAcquirer

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



83
84
85
86
87
88
89
90
91
# File 'lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb', line 83

def self.create(mapObj)
    #
    #Creates object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("b06ca8e0-8500-43d1-8a51-ffd96f6a12df", ChargebacksDebitMasterCardAndEuropeDualAcquirer.new(mapObj))
end

.createReversal(mapObj) ⇒ Object



99
100
101
102
103
104
105
106
107
# File 'lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb', line 99

def self.createReversal(mapObj)
    #
    #Creates object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("4592f076-7e12-4c77-9bce-eff49e2714c9", ChargebacksDebitMasterCardAndEuropeDualAcquirer.new(mapObj))
end

.retrieveDocumentation(criteria) ⇒ Object



120
121
122
123
124
125
126
127
128
129
# File 'lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb', line 120

def self.retrieveDocumentation(criteria)
    #
    #Query objects of type ChargebacksDebitMasterCardAndEuropeDualAcquirer by id and optional criteria
    #@param [Dict] criteria
    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("e21a4f6c-cd0d-4b6c-8fb4-d1551e982efb",ChargebacksDebitMasterCardAndEuropeDualAcquirer.new(criteria))
end

Instance Method Details

#acknowledgeReceivedChargebacksObject



67
68
69
70
71
72
73
74
75
# File 'lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb', line 67

def acknowledgeReceivedChargebacks
    #
    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
    #
    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("ef8e22f4-70e1-48be-8ee2-e07afdcab248",self)
end

#chargebacksImageStatusObject



133
134
135
136
137
138
139
140
141
# File 'lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb', line 133

def chargebacksImageStatus
    #
    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
    #
    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("e39fa0db-40fb-4260-ac04-5cd7a3428ca1",self)
end

#chargebacksStatusObject



150
151
152
153
154
155
156
157
158
# File 'lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb', line 150

def chargebacksStatus
    #
    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
    #
    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("1af2985f-9fe2-438a-9a9e-a152ed1ef2ec",self)
end

#updateObject



167
168
169
170
171
172
173
174
175
# File 'lib/mastercard/api/mastercom/chargebacksdebitmastercardandeuropedualacquirer.rb', line 167

def update
    #
    #Updates an object of type ChargebacksDebitMasterCardAndEuropeDualAcquirer
    #
    #@return [ChargebacksDebitMasterCardAndEuropeDualAcquirer] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("28d4f54b-8822-43ec-a591-e8a8af552c86",self)
end