Class: MasterCard::API::Mastercom::Fees
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Fees
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/fees.rb
Class Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
61 62 63 64 65 66 67 68 69 |
# File 'lib/mastercard/api/mastercom/fees.rb', line 61 def self.create(mapObj) # #Creates object of type Fees # #@param Dict mapObj, containing the required parameters to create a new object #@return [Fees] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("fd0e534e-8d7a-4335-bb62-d498afeabe03", Fees.new(mapObj)) end |
.getPossibleValueListsForCreate(mapObj) ⇒ Object
77 78 79 80 81 82 83 84 85 |
# File 'lib/mastercard/api/mastercom/fees.rb', line 77 def self.getPossibleValueListsForCreate(mapObj) # #Creates object of type Fees # #@param Dict mapObj, containing the required parameters to create a new object #@return [Fees] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("c06690e9-e1d6-4baf-8c2f-60d580c6c4d6", Fees.new(mapObj)) end |