Class: MasterCard::API::Mastercom::Chargebacks
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Chargebacks
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/chargebacks.rb
Class Method Summary collapse
- .create(mapObj) ⇒ Object
- .createReversal(mapObj) ⇒ Object
- .getPossibleValueListsForCreate(mapObj) ⇒ Object
- .retrieveDocumentation(criteria) ⇒ Object
Instance Method Summary collapse
- #acknowledgeReceivedChargebacks ⇒ Object
- #chargebacksImageStatus ⇒ Object
- #chargebacksStatus ⇒ Object
- #update ⇒ Object
Class Method Details
.create(mapObj) ⇒ Object
84 85 86 87 88 89 90 91 92 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 84 def self.create(mapObj) # #Creates object of type Chargebacks # #@param Dict mapObj, containing the required parameters to create a new object #@return [Chargebacks] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("ca091d42-b276-4aef-ae56-b1e95e55a99e", Chargebacks.new(mapObj)) end |
.createReversal(mapObj) ⇒ Object
100 101 102 103 104 105 106 107 108 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 100 def self.createReversal(mapObj) # #Creates object of type Chargebacks # #@param Dict mapObj, containing the required parameters to create a new object #@return [Chargebacks] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("b58a232b-d210-46bf-8b18-a193395eff11", Chargebacks.new(mapObj)) end |
.getPossibleValueListsForCreate(mapObj) ⇒ Object
133 134 135 136 137 138 139 140 141 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 133 def self.getPossibleValueListsForCreate(mapObj) # #Creates object of type Chargebacks # #@param Dict mapObj, containing the required parameters to create a new object #@return [Chargebacks] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("9cc03deb-b81e-4fe0-8933-a591c98ed923", Chargebacks.new(mapObj)) end |
.retrieveDocumentation(criteria) ⇒ Object
121 122 123 124 125 126 127 128 129 130 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 121 def self.retrieveDocumentation(criteria) # #Query objects of type Chargebacks by id and optional criteria #@param [Dict] criteria #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("6446ea44-6ee5-4588-bf6d-9ff4b982686a",Chargebacks.new(criteria)) end |
Instance Method Details
#acknowledgeReceivedChargebacks ⇒ Object
68 69 70 71 72 73 74 75 76 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 68 def acknowledgeReceivedChargebacks # #Updates an object of type Chargebacks # #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("588c531a-c9d6-43f6-b49a-4a1be86d539d",self) end |
#chargebacksImageStatus ⇒ Object
150 151 152 153 154 155 156 157 158 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 150 def chargebacksImageStatus # #Updates an object of type Chargebacks # #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("a2a59b0e-0df3-40ac-a153-46534e62c805",self) end |
#chargebacksStatus ⇒ Object
167 168 169 170 171 172 173 174 175 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 167 def chargebacksStatus # #Updates an object of type Chargebacks # #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("aa597b5a-aa38-4764-b406-d1dad2a25148",self) end |
#update ⇒ Object
184 185 186 187 188 189 190 191 192 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 184 def update # #Updates an object of type Chargebacks # #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("379697f2-8aa9-41f0-b738-06bfe83566fe",self) end |