Class: MasterCard::API::Mastercom::Chargebacks

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/chargebacks.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



84
85
86
87
88
89
90
91
92
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 84

def self.create(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("4f83fc09-c144-4a24-8de9-ad6fe8022b8c", Chargebacks.new(mapObj))
end

.createReversal(mapObj) ⇒ Object



100
101
102
103
104
105
106
107
108
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 100

def self.createReversal(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("cdfb4637-c7bc-4220-8a11-76acdddf6bb5", Chargebacks.new(mapObj))
end

.getPossibleValueListsForCreate(mapObj) ⇒ Object



133
134
135
136
137
138
139
140
141
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 133

def self.getPossibleValueListsForCreate(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("bb3f698a-4159-4ad7-bcc6-befab45939e0", Chargebacks.new(mapObj))
end

.retrieveDocumentation(criteria) ⇒ Object



121
122
123
124
125
126
127
128
129
130
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 121

def self.retrieveDocumentation(criteria)
    #
    #Query objects of type Chargebacks by id and optional criteria
    #@param [Dict] criteria
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("ab2f2634-6537-45ac-a172-edbbb1386a7f",Chargebacks.new(criteria))
end

Instance Method Details

#acknowledgeReceivedChargebacksObject



68
69
70
71
72
73
74
75
76
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 68

def acknowledgeReceivedChargebacks
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("3ff24451-6e6f-4347-9fa2-d3bea60372ea",self)
end

#chargebacksImageStatusObject



150
151
152
153
154
155
156
157
158
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 150

def chargebacksImageStatus
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("20c82283-d9d8-4103-8209-a05fadab0cc1",self)
end

#chargebacksStatusObject



167
168
169
170
171
172
173
174
175
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 167

def chargebacksStatus
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("cd799e76-3587-42cd-9aab-6cab6fce2b9d",self)
end

#updateObject



184
185
186
187
188
189
190
191
192
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 184

def update
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("edd8fc58-9297-4bf1-82c5-81ef451ab45d",self)
end