Class: MasterCard::API::Mastercom::Chargebacks

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/chargebacks.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



83
84
85
86
87
88
89
90
91
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 83

def self.create(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("43c2ec4f-3477-4807-b60e-e814632ff532", Chargebacks.new(mapObj))
end

.createReversal(mapObj) ⇒ Object



99
100
101
102
103
104
105
106
107
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 99

def self.createReversal(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("8d07538a-a9f0-4cee-b6fd-fa1041dca479", Chargebacks.new(mapObj))
end

.getPossibleValueListsForCreate(mapObj) ⇒ Object



132
133
134
135
136
137
138
139
140
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 132

def self.getPossibleValueListsForCreate(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("d625939a-53ca-44d9-96d9-c31083ddd02e", Chargebacks.new(mapObj))
end

.retrieveDocumentation(criteria) ⇒ Object



120
121
122
123
124
125
126
127
128
129
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 120

def self.retrieveDocumentation(criteria)
    #
    #Query objects of type Chargebacks by id and optional criteria
    #@param [Dict] criteria
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("a6b8f55f-13a6-49f6-a301-8a455d46cfb8",Chargebacks.new(criteria))
end

Instance Method Details

#acknowledgeReceivedChargebacksObject



67
68
69
70
71
72
73
74
75
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 67

def acknowledgeReceivedChargebacks
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("ca0dc3b6-986c-45b8-ba34-f10da7e644ad",self)
end

#chargebacksStatusObject



149
150
151
152
153
154
155
156
157
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 149

def chargebacksStatus
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("f4b1d35b-16b3-4cca-b54c-3e691ee27523",self)
end

#updateObject



166
167
168
169
170
171
172
173
174
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 166

def update
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("2a81a6bd-1a0e-4be6-8f76-32cf5d81f001",self)
end