Class: MasterCard::API::Mastercom::Chargebacks

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/chargebacks.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



83
84
85
86
87
88
89
90
91
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 83

def self.create(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("502aca5a-c44f-44f7-b011-4406d669ade2", Chargebacks.new(mapObj))
end

.createReversal(mapObj) ⇒ Object



99
100
101
102
103
104
105
106
107
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 99

def self.createReversal(mapObj)
    #
    #Creates object of type Chargebacks
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Chargebacks] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("d3e597d2-6bb7-409a-86ab-c3014fd49393", Chargebacks.new(mapObj))
end

.getPossibleValueListsForCreate(criteria) ⇒ Object



137
138
139
140
141
142
143
144
145
146
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 137

def self.getPossibleValueListsForCreate(criteria)
    #
    #Query objects of type Chargebacks by id and optional criteria
    #@param [Dict] criteria
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("bc0f68b4-7984-4e83-943a-40b99dd21c8a",Chargebacks.new(criteria))
end

.retrieveDocumentation(criteria) ⇒ Object



120
121
122
123
124
125
126
127
128
129
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 120

def self.retrieveDocumentation(criteria)
    #
    #Query objects of type Chargebacks by id and optional criteria
    #@param [Dict] criteria
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("2adaaa0d-3ee9-4cc6-a382-9a2e51c93397",Chargebacks.new(criteria))
end

Instance Method Details

#acknowledgeReceivedChargebacksObject



67
68
69
70
71
72
73
74
75
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 67

def acknowledgeReceivedChargebacks
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("3e0f3247-0473-4ee8-9a2d-17d0777f3b83",self)
end

#chargebacksStatusObject



150
151
152
153
154
155
156
157
158
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 150

def chargebacksStatus
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("60bbbb77-58ff-470f-ba6c-30ae838c9d20",self)
end

#updateObject



167
168
169
170
171
172
173
174
175
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 167

def update
    #
    #Updates an object of type Chargebacks
    #
    #@return [Chargebacks] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("49d92a0d-4904-464b-96cc-53cdc88cdd6a",self)
end