Class: MasterCard::API::Mastercom::Chargebacks
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Chargebacks
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/chargebacks.rb
Class Method Summary collapse
- .create(mapObj) ⇒ Object
- .createReversal(mapObj) ⇒ Object
- .getPossibleValueListsForCreate(criteria) ⇒ Object
- .retrieveDocumentation(criteria) ⇒ Object
Instance Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
64 65 66 67 68 69 70 71 72 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 64 def self.create(mapObj) # #Creates object of type Chargebacks # #@param Dict mapObj, containing the required parameters to create a new object #@return [Chargebacks] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("3599e7fc-bb22-424f-a310-beb39f7598eb", Chargebacks.new(mapObj)) end |
.createReversal(mapObj) ⇒ Object
80 81 82 83 84 85 86 87 88 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 80 def self.createReversal(mapObj) # #Creates object of type Chargebacks # #@param Dict mapObj, containing the required parameters to create a new object #@return [Chargebacks] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("9b86f645-9868-433f-9b03-4af1e2f2a9fb", Chargebacks.new(mapObj)) end |
.getPossibleValueListsForCreate(criteria) ⇒ Object
118 119 120 121 122 123 124 125 126 127 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 118 def self.getPossibleValueListsForCreate(criteria) # #Query objects of type Chargebacks by id and optional criteria #@param [Dict] criteria #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("ca9a61a9-043d-487e-935e-c2f52b8a949f",Chargebacks.new(criteria)) end |
.retrieveDocumentation(criteria) ⇒ Object
101 102 103 104 105 106 107 108 109 110 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 101 def self.retrieveDocumentation(criteria) # #Query objects of type Chargebacks by id and optional criteria #@param [Dict] criteria #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("833e3108-d43a-4001-9247-fbc64f657d4d",Chargebacks.new(criteria)) end |
Instance Method Details
#update ⇒ Object
131 132 133 134 135 136 137 138 139 |
# File 'lib/mastercard/api/mastercom/chargebacks.rb', line 131 def update # #Updates an object of type Chargebacks # #@return [Chargebacks] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("35e67f00-00b3-4b20-976b-7e96486f93a8",self) end |