Class: MasterCard::API::Mastercom::Fees

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/fees.rb

Class Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



61
62
63
64
65
66
67
68
69
# File 'lib/mastercard/api/mastercom/fees.rb', line 61

def self.create(mapObj)
    #
    #Creates object of type Fees
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Fees] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("7ecb8f8f-bcd1-4960-9afe-b0ef840b834b", Fees.new(mapObj))
end

.getPossibleValueListsForCreate(mapObj) ⇒ Object



77
78
79
80
81
82
83
84
85
# File 'lib/mastercard/api/mastercom/fees.rb', line 77

def self.getPossibleValueListsForCreate(mapObj)
    #
    #Creates object of type Fees
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Fees] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("4467e686-6b95-4446-9dda-2fc5ba1d83bb", Fees.new(mapObj))
end