Class: MasterCard::API::Mastercom::Fees
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Fees
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/fees.rb
Class Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
61 62 63 64 65 66 67 68 69 |
# File 'lib/mastercard/api/mastercom/fees.rb', line 61 def self.create(mapObj) # #Creates object of type Fees # #@param Dict mapObj, containing the required parameters to create a new object #@return [Fees] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("311b1e2e-b7f7-4096-a9d1-fee3ff911203", Fees.new(mapObj)) end |
.getPossibleValueListsForCreate(mapObj) ⇒ Object
77 78 79 80 81 82 83 84 85 |
# File 'lib/mastercard/api/mastercom/fees.rb', line 77 def self.getPossibleValueListsForCreate(mapObj) # #Creates object of type Fees # #@param Dict mapObj, containing the required parameters to create a new object #@return [Fees] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("61efe6c7-167c-4251-8357-cfec3e081832", Fees.new(mapObj)) end |