Class: MasterCard::API::Mastercom::Fees
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Fees
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/fees.rb
Class Method Summary collapse
Class Method Details
.create(mapObj) ⇒ Object
61 62 63 64 65 66 67 68 69 |
# File 'lib/mastercard/api/mastercom/fees.rb', line 61 def self.create(mapObj) # #Creates object of type Fees # #@param Dict mapObj, containing the required parameters to create a new object #@return [Fees] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("c7c3a9e6-2219-4fc7-9da3-54a14e42466a", Fees.new(mapObj)) end |
.getPossibleValueListsForCreate(criteria) ⇒ Object
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/mastercard/api/mastercom/fees.rb', line 82 def self.getPossibleValueListsForCreate(criteria) # #Query objects of type Fees by id and optional criteria #@param [Dict] criteria #@return [Fees] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("be232cdd-5495-4436-9446-b1664dd55776",Fees.new(criteria)) end |