Class: MasterCard::API::Mastercom::Fees

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/fees.rb

Class Method Summary collapse

Class Method Details

.create(mapObj) ⇒ Object



61
62
63
64
65
66
67
68
69
# File 'lib/mastercard/api/mastercom/fees.rb', line 61

def self.create(mapObj)
	#
	#Creates object of type Fees
	#
	#@param Dict mapObj, containing the required parameters to create a new object
	#@return [Fees] of the response of created instance.
	#@raise [APIException] an exception from the response status
	return self.execute("ccf86960-d140-47bd-ab1f-1e05c93ce380", Fees.new(mapObj))
end

.getPossibleValueListsForCreate(criteria) ⇒ Object



82
83
84
85
86
87
88
89
90
91
# File 'lib/mastercard/api/mastercom/fees.rb', line 82

def self.getPossibleValueListsForCreate(criteria)
	#
	#Query objects of type Fees by id and optional criteria
	#@param [Dict] criteria
	#@return [Fees] object representing the response.
	#@raise [APIException] an exception from the response status
	#

	return self.execute("7d5eb775-8ea7-467c-9559-ef61ee1b9ddd",Fees.new(criteria))
end