Class: MasterCard::API::Mastercom::Fraud
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Fraud
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/fraud.rb
Class Method Summary collapse
Class Method Details
.createForMasterCard(mapObj) ⇒ Object
61 62 63 64 65 66 67 68 69 |
# File 'lib/mastercard/api/mastercom/fraud.rb', line 61 def self.createForMasterCard(mapObj) # #Creates object of type Fraud # #@param Dict mapObj, containing the required parameters to create a new object #@return [Fraud] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("d32268b4-3539-4798-a326-e603b742f427", Fraud.new(mapObj)) end |
.getPossibleValueListsForCreate(criteria) ⇒ Object
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/mastercard/api/mastercom/fraud.rb', line 82 def self.getPossibleValueListsForCreate(criteria) # #Query objects of type Fraud by id and optional criteria #@param [Dict] criteria #@return [Fraud] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("040aeaa5-f87d-4968-9cb4-c107572f1144",Fraud.new(criteria)) end |