Class: MasterCard::API::Mastercom::Fraud

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/fraud.rb

Class Method Summary collapse

Class Method Details

.createForMasterCard(mapObj) ⇒ Object



61
62
63
64
65
66
67
68
69
# File 'lib/mastercard/api/mastercom/fraud.rb', line 61

def self.createForMasterCard(mapObj)
    #
    #Creates object of type Fraud
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Fraud] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("9b1e5de9-68f9-4acc-bacf-10289a3b4125", Fraud.new(mapObj))
end

.getPossibleValueListsForCreate(criteria) ⇒ Object



82
83
84
85
86
87
88
89
90
91
# File 'lib/mastercard/api/mastercom/fraud.rb', line 82

def self.getPossibleValueListsForCreate(criteria)
    #
    #Query objects of type Fraud by id and optional criteria
    #@param [Dict] criteria
    #@return [Fraud] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("a104c8bd-b737-4502-8a75-c282d976a0a8",Fraud.new(criteria))
end