Class: MasterCard::API::Mastercom::Reconciliation
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Reconciliation
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/reconciliation.rb
Class Method Summary collapse
Class Method Details
.acknowledgeReconciliationRequest(mapObj) ⇒ Object
61 62 63 64 65 66 67 68 69 |
# File 'lib/mastercard/api/mastercom/reconciliation.rb', line 61 def self.acknowledgeReconciliationRequest(mapObj) # #Creates object of type Reconciliation # #@param Dict mapObj, containing the required parameters to create a new object #@return [Reconciliation] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("2e8a9c9d-21bb-495b-ac2c-214e593ecdf1", Reconciliation.new(mapObj)) end |
.retrieveReconciliationReport(mapObj) ⇒ Object
77 78 79 80 81 82 83 84 85 |
# File 'lib/mastercard/api/mastercom/reconciliation.rb', line 77 def self.retrieveReconciliationReport(mapObj) # #Creates object of type Reconciliation # #@param Dict mapObj, containing the required parameters to create a new object #@return [Reconciliation] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("944ead22-d033-43aa-a9c2-d80617764c0b", Reconciliation.new(mapObj)) end |