Class: MasterCard::API::Mastercom::Retrievals
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Retrievals
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/retrievals.rb
Class Method Summary collapse
- .acquirerFulfillARequest(mapObj) ⇒ Object
- .create(mapObj) ⇒ Object
- .getDocumentation(criteria) ⇒ Object
- .getPossibleValueListsForCreate(criteria) ⇒ Object
- .issuerRespondToFulfillment(mapObj) ⇒ Object
Instance Method Summary collapse
Class Method Details
.acquirerFulfillARequest(mapObj) ⇒ Object
66 67 68 69 70 71 72 73 74 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 66 def self.acquirerFulfillARequest(mapObj) # #Creates object of type Retrievals # #@param Dict mapObj, containing the required parameters to create a new object #@return [Retrievals] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("d03035fd-3942-4377-9cff-21e393b96584", Retrievals.new(mapObj)) end |
.create(mapObj) ⇒ Object
82 83 84 85 86 87 88 89 90 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 82 def self.create(mapObj) # #Creates object of type Retrievals # #@param Dict mapObj, containing the required parameters to create a new object #@return [Retrievals] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("a709265e-88bf-4429-8777-5b1f720a38a8", Retrievals.new(mapObj)) end |
.getDocumentation(criteria) ⇒ Object
120 121 122 123 124 125 126 127 128 129 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 120 def self.getDocumentation(criteria) # #Query objects of type Retrievals by id and optional criteria #@param [Dict] criteria #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("67265be7-e570-4f4e-a371-9c5092235596",Retrievals.new(criteria)) end |
.getPossibleValueListsForCreate(criteria) ⇒ Object
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 103 def self.getPossibleValueListsForCreate(criteria) # #Query objects of type Retrievals by id and optional criteria #@param [Dict] criteria #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("d095c8ac-13fb-49c1-83ad-18320feff275",Retrievals.new(criteria)) end |
.issuerRespondToFulfillment(mapObj) ⇒ Object
132 133 134 135 136 137 138 139 140 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 132 def self.issuerRespondToFulfillment(mapObj) # #Creates object of type Retrievals # #@param Dict mapObj, containing the required parameters to create a new object #@return [Retrievals] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("8278b386-1f63-4895-962f-a99a3bb4e073", Retrievals.new(mapObj)) end |
Instance Method Details
#retrievalFullfilmentImageStatus ⇒ Object
149 150 151 152 153 154 155 156 157 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 149 def retrievalFullfilmentImageStatus # #Updates an object of type Retrievals # #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("30cf12bc-4b59-497b-8fad-dc2de1c3a0d6",self) end |
#retrievalFullfilmentStatus ⇒ Object
166 167 168 169 170 171 172 173 174 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 166 def retrievalFullfilmentStatus # #Updates an object of type Retrievals # #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("49dcb35c-cdc0-46a6-a01a-0fce5c329d85",self) end |