Class: MasterCard::API::Mastercom::Retrievals
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::Retrievals
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/retrievals.rb
Class Method Summary collapse
- .acquirerFulfillARequest(mapObj) ⇒ Object
- .create(mapObj) ⇒ Object
- .getDocumentation(criteria) ⇒ Object
- .getPossibleValueListsForCreate(criteria) ⇒ Object
- .issuerRespondToFulfillment(mapObj) ⇒ Object
Instance Method Summary collapse
Class Method Details
.acquirerFulfillARequest(mapObj) ⇒ Object
66 67 68 69 70 71 72 73 74 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 66 def self.acquirerFulfillARequest(mapObj) # #Creates object of type Retrievals # #@param Dict mapObj, containing the required parameters to create a new object #@return [Retrievals] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("a23527dc-0999-4350-abf2-e1ea8fd41e56", Retrievals.new(mapObj)) end |
.create(mapObj) ⇒ Object
82 83 84 85 86 87 88 89 90 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 82 def self.create(mapObj) # #Creates object of type Retrievals # #@param Dict mapObj, containing the required parameters to create a new object #@return [Retrievals] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("f1c63dac-3e79-48d6-ac08-b70aca70670a", Retrievals.new(mapObj)) end |
.getDocumentation(criteria) ⇒ Object
120 121 122 123 124 125 126 127 128 129 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 120 def self.getDocumentation(criteria) # #Query objects of type Retrievals by id and optional criteria #@param [Dict] criteria #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("6293b3e9-8c29-4d3b-a553-148f6f1af0b9",Retrievals.new(criteria)) end |
.getPossibleValueListsForCreate(criteria) ⇒ Object
103 104 105 106 107 108 109 110 111 112 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 103 def self.getPossibleValueListsForCreate(criteria) # #Query objects of type Retrievals by id and optional criteria #@param [Dict] criteria #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("d0f3abc3-bf08-4b5c-8e7d-944e6a9240d8",Retrievals.new(criteria)) end |
.issuerRespondToFulfillment(mapObj) ⇒ Object
132 133 134 135 136 137 138 139 140 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 132 def self.issuerRespondToFulfillment(mapObj) # #Creates object of type Retrievals # #@param Dict mapObj, containing the required parameters to create a new object #@return [Retrievals] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("a3ad68ce-11f5-454b-89cf-f2a0875c7d36", Retrievals.new(mapObj)) end |
Instance Method Details
#retrievalFullfilmentImageStatus ⇒ Object
149 150 151 152 153 154 155 156 157 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 149 def retrievalFullfilmentImageStatus # #Updates an object of type Retrievals # #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("067588d5-20cb-4e37-b44b-b6f015911203",self) end |
#retrievalFullfilmentStatus ⇒ Object
166 167 168 169 170 171 172 173 174 |
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 166 def retrievalFullfilmentStatus # #Updates an object of type Retrievals # #@return [Retrievals] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("97c76e88-0b5c-4ecd-8a49-1e00744e0880",self) end |