Class: MasterCard::API::Mastercom::Retrievals

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/retrievals.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.acquirerFulfillARequest(mapObj) ⇒ Object



65
66
67
68
69
70
71
72
73
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 65

def self.acquirerFulfillARequest(mapObj)
    #
    #Creates object of type Retrievals
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Retrievals] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("f4d20ea7-96fc-4ff2-8fa0-fab081fb741e", Retrievals.new(mapObj))
end

.create(mapObj) ⇒ Object



81
82
83
84
85
86
87
88
89
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 81

def self.create(mapObj)
    #
    #Creates object of type Retrievals
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Retrievals] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("16d0ab68-0f1b-4e58-a1cc-8576b6eac9d0", Retrievals.new(mapObj))
end

.getDocumentation(criteria) ⇒ Object



119
120
121
122
123
124
125
126
127
128
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 119

def self.getDocumentation(criteria)
    #
    #Query objects of type Retrievals by id and optional criteria
    #@param [Dict] criteria
    #@return [Retrievals] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("a9b1b8b0-d719-44ea-aacd-aedb7d453ea7",Retrievals.new(criteria))
end

.getPossibleValueListsForCreate(criteria) ⇒ Object



102
103
104
105
106
107
108
109
110
111
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 102

def self.getPossibleValueListsForCreate(criteria)
    #
    #Query objects of type Retrievals by id and optional criteria
    #@param [Dict] criteria
    #@return [Retrievals] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("96fbf0a5-c504-4c6e-acb1-e89f6c62ea91",Retrievals.new(criteria))
end

.issuerRespondToFulfillment(mapObj) ⇒ Object



131
132
133
134
135
136
137
138
139
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 131

def self.issuerRespondToFulfillment(mapObj)
    #
    #Creates object of type Retrievals
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Retrievals] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("de51cd40-deab-46b6-a8d0-9cbc2401fd98", Retrievals.new(mapObj))
end

Instance Method Details

#retrievalFullfilmentStatusObject



148
149
150
151
152
153
154
155
156
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 148

def retrievalFullfilmentStatus
    #
    #Updates an object of type Retrievals
    #
    #@return [Retrievals] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("0c8aeb20-e894-4891-b30b-1e31f0c3d70d",self)
end