Class: MasterCard::API::Mastercom::Retrievals

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/retrievals.rb

Class Method Summary collapse

Instance Method Summary collapse

Class Method Details

.acquirerFulfillARequest(mapObj) ⇒ Object



65
66
67
68
69
70
71
72
73
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 65

def self.acquirerFulfillARequest(mapObj)
    #
    #Creates object of type Retrievals
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Retrievals] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("76025c66-ac44-45e3-bc19-b04d8bdfd9d6", Retrievals.new(mapObj))
end

.create(mapObj) ⇒ Object



81
82
83
84
85
86
87
88
89
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 81

def self.create(mapObj)
    #
    #Creates object of type Retrievals
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Retrievals] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("e45e1d44-99e7-4345-abb7-ea1ffa5a6e5c", Retrievals.new(mapObj))
end

.getDocumentation(criteria) ⇒ Object



119
120
121
122
123
124
125
126
127
128
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 119

def self.getDocumentation(criteria)
    #
    #Query objects of type Retrievals by id and optional criteria
    #@param [Dict] criteria
    #@return [Retrievals] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("fc93cda1-0c23-4c0d-acd9-1d5575d03ada",Retrievals.new(criteria))
end

.getPossibleValueListsForCreate(criteria) ⇒ Object



102
103
104
105
106
107
108
109
110
111
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 102

def self.getPossibleValueListsForCreate(criteria)
    #
    #Query objects of type Retrievals by id and optional criteria
    #@param [Dict] criteria
    #@return [Retrievals] object representing the response.
    #@raise [APIException] an exception from the response status
    #

    return self.execute("2ec06c26-2e8b-46b2-ba93-507ae33b8bf4",Retrievals.new(criteria))
end

.issuerRespondToFulfillment(mapObj) ⇒ Object



131
132
133
134
135
136
137
138
139
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 131

def self.issuerRespondToFulfillment(mapObj)
    #
    #Creates object of type Retrievals
    #
    #@param Dict mapObj, containing the required parameters to create a new object
    #@return [Retrievals] of the response of created instance.
    #@raise [APIException] an exception from the response status
    return self.execute("04cc9c49-6a8e-4763-ae53-3ddb17dc67f0", Retrievals.new(mapObj))
end

Instance Method Details

#retrievalFullfilmentStatusObject



148
149
150
151
152
153
154
155
156
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 148

def retrievalFullfilmentStatus
    #
    #Updates an object of type Retrievals
    #
    #@return [Retrievals] object representing the response.
    #@raise [APIException] an exception from the response status
    #
    return self.class.execute("a9b3c83a-63db-435b-a0d3-b58ccc2ed4e8",self)
end