Class: MasterCard::API::Mastercom::Retrievals

Inherits:
Core::Model::BaseObject
  • Object
show all
Includes:
Core::Model
Defined in:
lib/mastercard/api/mastercom/retrievals.rb

Class Method Summary collapse

Class Method Details

.acquirerFulfillARequest(mapObj) ⇒ Object



64
65
66
67
68
69
70
71
72
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 64

def self.acquirerFulfillARequest(mapObj)
  #
  #Creates object of type Retrievals
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Retrievals] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("9a20747a-8d09-48f8-b8a7-af51715187c9", Retrievals.new(mapObj))
end

.create(mapObj) ⇒ Object



80
81
82
83
84
85
86
87
88
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 80

def self.create(mapObj)
  #
  #Creates object of type Retrievals
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Retrievals] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("60bf9970-1aeb-4e65-8e64-8a9d7f7e9818", Retrievals.new(mapObj))
end

.getDocumentation(criteria) ⇒ Object



118
119
120
121
122
123
124
125
126
127
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 118

def self.getDocumentation(criteria)
  #
  #Query objects of type Retrievals by id and optional criteria
  #@param [Dict] criteria
  #@return [Retrievals] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("7634df7d-12ca-4abf-a9bd-736ba3a13afe",Retrievals.new(criteria))
end

.getPossibleValueListsForCreate(criteria) ⇒ Object



101
102
103
104
105
106
107
108
109
110
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 101

def self.getPossibleValueListsForCreate(criteria)
  #
  #Query objects of type Retrievals by id and optional criteria
  #@param [Dict] criteria
  #@return [Retrievals] object representing the response.
  #@raise [APIException] an exception from the response status
  #

  return self.execute("77000b47-d95c-4192-9299-47f91fef7544",Retrievals.new(criteria))
end

.issuerRespondToFulfillment(mapObj) ⇒ Object



130
131
132
133
134
135
136
137
138
# File 'lib/mastercard/api/mastercom/retrievals.rb', line 130

def self.issuerRespondToFulfillment(mapObj)
  #
  #Creates object of type Retrievals
  #
  #@param Dict mapObj, containing the required parameters to create a new object
  #@return [Retrievals] of the response of created instance.
  #@raise [APIException] an exception from the response status
  return self.execute("49230f0e-1fd8-443c-8404-b58337677fa1", Retrievals.new(mapObj))
end