Class: MasterCard::API::Mastercom::RetrievalsDebitMasterCardAndEuropeDualAcquirer
- Inherits:
-
Core::Model::BaseObject
- Object
- Core::Model::BaseObject
- MasterCard::API::Mastercom::RetrievalsDebitMasterCardAndEuropeDualAcquirer
- Includes:
- Core::Model
- Defined in:
- lib/mastercard/api/mastercom/retrievalsdebitmastercardandeuropedualacquirer.rb
Class Method Summary collapse
- .acquirerFulfillARequest(mapObj) ⇒ Object
- .create(mapObj) ⇒ Object
- .getDocumentation(criteria) ⇒ Object
- .issuerRespondToFulfillment(mapObj) ⇒ Object
Instance Method Summary collapse
Class Method Details
.acquirerFulfillARequest(mapObj) ⇒ Object
65 66 67 68 69 70 71 72 73 |
# File 'lib/mastercard/api/mastercom/retrievalsdebitmastercardandeuropedualacquirer.rb', line 65 def self.acquirerFulfillARequest(mapObj) # #Creates object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer # #@param Dict mapObj, containing the required parameters to create a new object #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("91beef53-418a-426b-82cd-d8c60b63a3ed", RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(mapObj)) end |
.create(mapObj) ⇒ Object
81 82 83 84 85 86 87 88 89 |
# File 'lib/mastercard/api/mastercom/retrievalsdebitmastercardandeuropedualacquirer.rb', line 81 def self.create(mapObj) # #Creates object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer # #@param Dict mapObj, containing the required parameters to create a new object #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("35ab623f-16f5-47f5-a4ab-008f243f3e4c", RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(mapObj)) end |
.getDocumentation(criteria) ⇒ Object
102 103 104 105 106 107 108 109 110 111 |
# File 'lib/mastercard/api/mastercom/retrievalsdebitmastercardandeuropedualacquirer.rb', line 102 def self.getDocumentation(criteria) # #Query objects of type RetrievalsDebitMasterCardAndEuropeDualAcquirer by id and optional criteria #@param [Dict] criteria #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] object representing the response. #@raise [APIException] an exception from the response status # return self.execute("2f4f611d-a575-45bc-b74b-e34a57d41745",RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(criteria)) end |
.issuerRespondToFulfillment(mapObj) ⇒ Object
114 115 116 117 118 119 120 121 122 |
# File 'lib/mastercard/api/mastercom/retrievalsdebitmastercardandeuropedualacquirer.rb', line 114 def self.issuerRespondToFulfillment(mapObj) # #Creates object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer # #@param Dict mapObj, containing the required parameters to create a new object #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] of the response of created instance. #@raise [APIException] an exception from the response status return self.execute("679740dc-e0cc-4a94-a688-9ff8687e19dd", RetrievalsDebitMasterCardAndEuropeDualAcquirer.new(mapObj)) end |
Instance Method Details
#retrievalFullfilmentImageStatus ⇒ Object
131 132 133 134 135 136 137 138 139 |
# File 'lib/mastercard/api/mastercom/retrievalsdebitmastercardandeuropedualacquirer.rb', line 131 def retrievalFullfilmentImageStatus # #Updates an object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer # #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("4176aff7-510f-4183-93bc-db0fca1c2e7d",self) end |
#retrievalFullfilmentStatus ⇒ Object
148 149 150 151 152 153 154 155 156 |
# File 'lib/mastercard/api/mastercom/retrievalsdebitmastercardandeuropedualacquirer.rb', line 148 def retrievalFullfilmentStatus # #Updates an object of type RetrievalsDebitMasterCardAndEuropeDualAcquirer # #@return [RetrievalsDebitMasterCardAndEuropeDualAcquirer] object representing the response. #@raise [APIException] an exception from the response status # return self.class.execute("4481c0a1-da44-44d9-8daa-9fbe935c58dd",self) end |